@@ -6,18 +6,18 @@ def yt(videourl, path="./Output"):
 
     clear()
     
-    print("Connecting...")
+    print("🔌Connecting...🔐 \n")
     
     yt = YouTube(videourl)
     yt = yt.streams.filter(progressive=True, file_extension='mp4').order_by('resolution').desc().first()
     
     if not os.path.exists(path):
-        print("Creating Folder...")
+        print("Creating Folder...\n")
         os.makedirs(path)
 
-    print("Downloading...")
+    print("⏬ Downloading...⏳\n")
     yt.download(path)
-    print("SucessFully Downloaded...")
+    print("✅ SucessFully Downloaded...\n")
 
 
 
@@ -33,6 +33,11 @@ def yt_download( url ):
         yt( url )
         
     elif type( url ) == list:
+
+        # todo - detected links : 
+        # todo - total file going to be downladed
+        # downloading {i} 
+        
         for link in url:
             yt( link )
     else:
